#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-yaml
version:              1.1.0.1
visibility:           public
id:                   aeson-yaml-1.1.0.1-C9cI121SGAx7tKbjbIqF4M
key:                  aeson-yaml-1.1.0.1-C9cI121SGAx7tKbjbIqF4M
license:              BSD-3-Clause
copyright:            2019 Clovyr LLC
maintainer:           patrick@clovyr.io
author:               Patrick Nielsen
homepage:             https://github.com/clovyr/aeson-yaml
synopsis:             Output any Aeson value as YAML (pure Haskell library)
description:
    This library exposes functions for encoding any Aeson value as YAML. There
    is also support for encoding multiple values into YAML "documents".

    This library is pure Haskell, and does not depend on C FFI with libyaml. It
    is also licensed under the BSD3 license.

category:             Text, Web, JSON, YAML
abi:                  e259e258c0095d4515d6f2e42066e362
exposed:              True
exposed-modules:      Data.Aeson.Yaml
import-dirs:          /usr/lib/ghc-9.6.6/site-local/aeson-yaml-1.1.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/aeson-yaml-1.1.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/aeson-yaml-1.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-yaml
hs-libraries:         HSaeson-yaml-1.1.0.1-C9cI121SGAx7tKbjbIqF4M
depends:
    aeson-2.2.1.0-FtPGfJZ8He1Ka7nmfurK0L base-4.18.2.1
    bytestring-0.11.5.3 text-2.0.2
    unordered-containers-0.2.20.1-HZplTUppwNB9GgXlMkO7HL
    vector-0.13.2.0-x1x4WBhPOiKZXEF9oDWBZ

haddock-interfaces:   /usr/share/doc/haskell-aeson-yaml/html/aeson-yaml.haddock
haddock-html:         /usr/share/doc/haskell-aeson-yaml/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

